# Document Formatting Act 2022

This document outlines the required usage of the CommonMark Markdown specification within Arsenio Pact documents for the purpose of standardization.

For information about the Markdown format not covered within the contents of this document, consult the [CommonMark Specification](https://spec.commonmark.org/).

This document was written by members of the Anyakovan Institute of Technology (AKIT) to promote concise writing & easy dissemination of legal material to the public.

## Motivation

There is an unnecessary overhead for auditors of the Arsenio Pact's documents, and a simple, foolproof standard would greatly improve the archival process.

Markdown is a good compromise between functionality & ease of use; it is readable as both plaintext or parsed in a variety of formats, namely HTML, PDF, or ODT.

The CommonMark specification is an ideal default specification to adhere to, due to its barebones feature set and loose formatting.

## Implementation

The Arsenio Pact & its member states must do the following:

+ Write all future documents in the CommonMark Markdown specification.
  + Documents must use the `.md`, `mkdn`, `.mdown`, or `.markdown` file extensions.
  + Documents must not use unsupported extensions of the Markdown format that are not present within CommonMark. This is especially important when converting documents using GFM (Github Flavoured Markdown).
  + For compatibility, documents must not contain inline HTML.
+ Convert all previous documents to Markdown.

Additionally, writers are encouraged (but not required) to do the following:

+ Use a proper CommonMark compatible editor, such as [VSCodium](https://vscodium.com/), [Atom](https://atom.io/), [Adobe Brackets](https://brackets.io/), or [MOME](markdown.pioul.fr/).
+ Use a Markdown Linter, such as [vscode-markdownlint](https://github.com/DavidAnson/vscode-markdownlint).

### Applicable Documents

The usage of the term "official document" describes legislation, treaties, guidelines, and any other information intended for distribution to an administrative body.

## Exemptions

This law may be reevaluated to further extend the list of supported formats.
Another format can be introduced if it adheres to the following:

+ Can be written without a compatible editor.
+ Can be quickly converted to HTML & PDF.

Common examples of compatible text formats include `.textile`, `.rdoc`, `.org`, `.creole`, `.mediawiki`/`wiki`, `.rst`, `.asciidoc`/`adoc`/`asc`, & `.pod`.
